@@ -157,6 +157,14 @@ class PluginPreferences(GObject.GObject, Thunarx.PreferencesProvider):
 
     def __open_plugin_preferences(self, action, window):
         dialog = self.ui.get_object("plugin-preferences-dialog")
+        version_label = self.ui.get_object("plugin-preferences-version-label")
+        version_label.set_markup(
+            '<a href="https://gitlab.com/nobodyinperson/thunar-plugins">'
+            "thunar-plugins</a> {version_str}: <tt>{version}</tt>"
+            "".format(
+                version_str=_("version"), version=thunar_plugins.__version__
+            )
+        )
         plugins_treestore = self.ui.get_object("plugins-treestore")
         plugins_treestore.clear()
         plugins_by_package = collections.defaultdict(list)
